@@ -19,8 +19,10 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-from mypy_boto3_secretsmanager.client import SecretsManagerClient, SecretsManagerClient as Client
+from mypy_boto3_secretsmanager.client import SecretsManagerClient
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 
+Client = SecretsManagerClient
+
 
 __all__ = ("Client", "ListSecretsPaginator", "SecretsManagerClient")
